(defun my-quit (exitcode)
  #+sbcl (sb-ext:quit :unix-status exitcode)
  ; fallthrough
  #-sbcl (when (not (zerop exitcode))
    (format *error-output* "I don't know how to give a unix exitcode for your platform, so I'm just exiting.~%Error code wuold have been ~A~%" exitcode)))

; No debugger in a script!
; cribbed from the SBCL manual
(setf *invoke-debugger-hook*
      (lambda (condition hook)
	(declare (ignore hook))
	;; Uncomment to get backtraces on errors
	;; (sb-debug:backtrace 20)
	(format *error-output* "Error: ~A~%" condition)
	(my-quit 1)))

(unless (eql '*default-pathname-defaults* (car asdf:*central-registry*))
  (push '*default-pathname-defaults* asdf:*central-registry*))
(map nil #'delete-file (directory #P"**/*.fasl"))


(defun ignore-warning (c)
  (declare (ignore c))
  (muffle-warning))

(defun yowl-warning (c)
  (print c)
  (muffle-warning))

(defun yowl-about-unhandled-condition (c)
  (format t "THE FOLLOWING ERROR IS UNHANDLED, UNCOUNTED, and UNEXPECTED!~%PLEASE INFORM A MAINTAINER~%~A~%" c)
  (muffle-warning))

(defvar *style-warnings* 0)
(defvar *serious-conditions* 0)

(defun compiler-report (stream)
  (format stream "Report:~%~2TStyle Warnings: ~A~%~2TSerious Conditions: ~A~%"
	  *style-warnings* *serious-conditions*)
  (if (zerop *serious-conditions*)
      (if (zerop *style-warnings*)
	  (format stream "PRISTINE!~%")
	  (format stream "SUCCESS~%"))
      (format stream "FAILURE~%")))

(defun condition-counter (type)
  (ecase type
    (style-warning (lambda (c)
		     (declare (ignore c))
		     (incf *style-warnings*)
		     (muffle-warning)))
    (serious-conditions (lambda (c)
			  (declare (ignore c))
			  (incf *serious-conditions*)))))

; If we encounter a serious condition, we'll error out with ERRNO 1
; the counting of serious conditions is just for show, really.
; Maybe in the future we'll want to have it attempt to keep going.
(handler-bind
    ((style-warning (condition-counter 'style-warning))
     (serious-condition (condition-counter 'serious-conditions))
     #+sbcl (sb-ext:compiler-note #'ignore-warning)
     #+sbcl (sb-ext:code-deletion-note #'ignore-warning))
  (restart-case (asdf:operate 'asdf:compile-op :araneida)
    (muffle-warning () nil)))

(compiler-report *error-output*)
(if (> *serious-conditions* 0)
    (my-quit 1)
    (my-quit 0))